@@ -52,11 +52,23 @@ constructTau <- function(lVs, indsLVs, parTable, mean.observed = TRUE) {
   numIndsLVs <- lapply(indsLVs, FUN = length)
   allIndsLVs <- unlist(indsLVs)
   numAllIndsLVs <- length(allIndsLVs)
+  lavOptimizerSyntaxAdditions <- ""
 
   if (mean.observed) default <- NA else default <- 0
 
   tau <- matrix(default, nrow = numAllIndsLVs, ncol = 1,
                 dimnames = list(allIndsLVs, "1"))
+  for (lV in lVs) { # set first ind to 0, if lV has meanstructure
+    if (NROW(parTable[parTable$lhs == lV & parTable$op == "~" & 
+             parTable$rhs == "1", ])) {
+      firstInd <- indsLVs[[lV]][[1]]
+      tau[firstInd, 1] <- 0 
+      lavOptimizerSyntaxAdditions <- 
+        getFixedInterceptSyntax(indicator = firstInd, parTable = parTable, 
+                                syntax = lavOptimizerSyntaxAdditions) 
+    }
+  }
+
   constExprs <- parTable[parTable$op == "~" & 
                          parTable$rhs == "1" &
                          parTable$lhs %in% allIndsLVs &
@@ -80,7 +92,7 @@ constructTau <- function(lVs, indsLVs, parTable, mean.observed = TRUE) {
     labelTau[lhs, 1] <- mod
   }
   
-  list(numeric = tau, label = labelTau)
+  list(numeric = tau, label = labelTau, syntaxAdditions = lavOptimizerSyntaxAdditions)
 }
 
 
@@ -334,6 +346,12 @@ selectBetaRows <- function(lambdaY, method = "qml") {
 
 constructR <- function(etas, indsEtas, lambdaY, method = "qml") {
   if (method != "qml") return(NULL)
+  hasMultipleInds <- vapply(indsEtas, FUN = function(x) length(x) > 1,
+                            FUN.VALUE = logical(1L))
+  etas <- names(indsEtas)[hasMultipleInds] 
+  indsEtas <- indsEtas[etas] 
+  if (length(etas) == 0) return(NULL)
+
   numEtas <- length(etas)
   numIndsEtas <- lapply(indsEtas, FUN = length)
   allIndsEtas <- unlist(indsEtas)
@@ -361,9 +379,102 @@ constructR <- function(etas, indsEtas, lambdaY, method = "qml") {
 }
 
 
-getScalingInds <- function(indsEtas, R, method = "qml") {
+getLatentEtasQml <- function(indsEtas, method = "qml") {
   if (method != "qml") return(NULL)
+  hasMultipleInds <- vapply(indsEtas, FUN = function(x) length(x) > 1,
+                            FUN.VALUE = logical(1L))
+  etas <- names(indsEtas)[hasMultipleInds]
+  if (length(etas) == 0) return(NULL)
+  etas
+}
+
+
+getColsU <- function(etas, indsEtas, lambdaY, method = "qml") {
+  numEtas <- length(etas)
+  numIndsEtas <- lapply(indsEtas, FUN = length)
   allIndsEtas <- unlist(indsEtas)
+  numAllIndsEtas <- length(allIndsEtas)
+  selectBetaRows <- selectBetaRows(lambdaY, method = "qml")
+  rowNamesR <- rownames(lambdaY)[selectBetaRows]
+  hasMultipleInds <- vapply(indsEtas, FUN = function(x) length(x) > 1,
+                            FUN.VALUE = logical(1L))
+  if (sum(hasMultipleInds) == 0) return(NULL) 
+  colsU <- rowNamesR[seq_len(numAllIndsEtas - sum(hasMultipleInds))]
+  colsU[is.na(colsU)] <- paste0("__FILL__ZERO__", seq_len(sum(is.na(colsU))))
+  colsU
+}
+
+
+constructFullU <- function(fullL2, N, etas, method = "qml") {
+  if (method != "qml" || N == 0) return(NULL)
+
+  if (is.null(fullL2)) nCols <- length(etas)
+  else nCols <- NCOL(fullL2)
+
+  matrix(0, nrow = N, ncol = nCols, dimnames = list(NULL, colnames(fullL2)))
+}
+
+
+constructFullR <- function(etas, indsEtas, lambdaY, method = "qml") {
+  if (method != "qml") return(NULL)
+
+  numEtas <- length(etas)
+  numIndsEtas <- lapply(indsEtas, FUN = length)
+  allIndsEtas <- unlist(indsEtas)
+  numAllIndsEtas <- length(allIndsEtas)
+  selectBetaRows <- selectBetaRows(lambdaY, method = "qml")
+  rowNamesR <- rownames(lambdaY)[selectBetaRows]
+  hasMultipleInds <- vapply(indsEtas, FUN = function(x) length(x) > 1,
+                            FUN.VALUE = logical(1L))
+  if (sum(hasMultipleInds) == 0) return(NULL) 
+
+  matrix(0, nrow = numAllIndsEtas - sum(hasMultipleInds), 
+         ncol = numAllIndsEtas, 
+         dimnames = list(rowNamesR[seq_len(numAllIndsEtas - sum(hasMultipleInds))],
+                                           allIndsEtas))
+
+}
+
+
+constructFullSigma2ThetaEpsilon <- function(psi, method = "qml") {
+  if (method != "qml") return(NULL)
+  matrix(0, nrow = nrow(psi), ncol = ncol(psi), 
+         dimnames = dimnames(psi))
+}
+
+
+getSelectSubSigma2ThetaEpsilon <- function(fullSigma2ThetaEpsilon, 
+                                           latentEtas, method = "qml") {
+  if (method != "qml") return(NULL)
+  select <- as.logical.matrix(fullSigma2ThetaEpsilon) 
+  select[TRUE] <- FALSE 
+  select[latentEtas, latentEtas] <- TRUE
+  select
+}
+
+
+constructFullL2 <- function(colsU, etas, method = "qml") {
+  if (method != "qml") return(NULL)
+  
+  if (is.null(colsU)) nCols <- length(etas)
+  else nCols <- length(colsU)
+  matrix(0, nrow = length(etas), ncol = nCols,
+         dimnames = list(etas, colsU))
+}
+
+
+getSelectSubL2 <- function(fullL2, colsU, latentEtas, method = "qml") {
+  if (method != "qml") return(NULL)
+  select <- as.logical.matrix(fullL2)
+  select[TRUE] <- FALSE
+  select[latentEtas, !grepl("__FILL__ZERO__", colnames(select))] <- TRUE
+  select
+}
+
+
+getScalingInds <- function(indsEtas, R, latentEtas, method = "qml") {
+  if (method != "qml") return(NULL)
+  allIndsEtas <- unlist(indsEtas[latentEtas])
   scalingInds <- allIndsEtas[!allIndsEtas %in% rownames(R)]
   scalingInds
 }
@@ -391,6 +502,16 @@ constructSubThetaEpsilon <- function(indsEtas, thetaEpsilon, scalingInds,
 }
 
 
+getScalingLambdaY <- function(lambdaY, indsEtas, etas, method = "qml") {
+  if (method != "qml") return(NULL)
+  hasMultipleInds <- vapply(indsEtas, FUN = function(x) length(x) > 1,
+                            FUN.VALUE = logical(1L))
+  latentEtas <- names(indsEtas)[hasMultipleInds] 
+  indsLatentEtas <- unlist(indsEtas[latentEtas])
+  lambdaY[indsLatentEtas, latentEtas]
+}
+
+
 sortXisConstructOmega <- function(xis, varsInts, etas, intTerms, 
                                   method = "lms", double = FALSE) {
   # allVarsInInts should be sorted according to which variables 
