@@ -5,7 +5,7 @@
 # Global variables 
 paramMatrices <- c("lambdaX", "lambdaY", "gammaXi", "gammaEta", 
                    "thetaDelta", "thetaEpsilon", "phi", "A",
-                   "psi", "tauX", "tauY", "alpha", "omegaEtaXi", 
+                   "psi", "tauX", "tauY", "alpha", "beta0", "omegaEtaXi", 
                    "omegaXiXi")
 
 
@@ -28,6 +28,9 @@ specifyModelDA <- function(syntax = NULL,
   if (!is.null(syntax)) parTable <- modsemify(syntax)
   if (is.null(parTable)) stop2("No parTable found")
 
+  # additions to lavaan-syntax for optimizer
+  lavOptimizerSyntaxAdditions <- ""
+
   # endogenous variables (etas)model
   etas <- getSortedEtas(parTable, isLV = TRUE, checkAny = TRUE)
   numEtas <- length(etas)
@@ -65,6 +68,8 @@ specifyModelDA <- function(syntax = NULL,
                            mean.observed = mean.observed)
   tauX <- listTauX$numeric 
   labelTauX <- listTauX$label
+  lavOptimizerSyntaxAdditions <- paste0(lavOptimizerSyntaxAdditions, 
+                                        listTauX$syntaxAdditions)
 
   listThetaDelta <- constructTheta(xis, indsXis, parTable = parTable,
                                    auto.constraints = auto.constraints)
@@ -75,12 +80,14 @@ specifyModelDA <- function(syntax = NULL,
   listLambdaY <- constructLambda(etas, indsEtas, parTable = parTable,
                                  auto.constraints = auto.constraints)
   lambdaY <- listLambdaY$numeric 
-  labelLambdaY <- listLambdaY$label 
+  labelLambdaY <- listLambdaY$label
 
   listTauY <- constructTau(etas, indsEtas, parTable = parTable,
                            mean.observed = mean.observed)
   tauY <- listTauY$numeric 
   labelTauY <- listTauY$label 
+  lavOptimizerSyntaxAdditions <- paste0(lavOptimizerSyntaxAdditions, 
+                                        listTauY$syntaxAdditions)
   
   listThetaEpsilon <- constructTheta(etas, indsEtas, parTable = parTable,
                                      auto.constraints = auto.constraints)
@@ -119,6 +126,13 @@ specifyModelDA <- function(syntax = NULL,
   alpha <- listAlpha$numeric
   labelAlpha <- listAlpha$label
 
+  # mean xis 
+  listBeta0 <- constructAlpha(xis, parTable = parTable, 
+                              auto.constraints = auto.constraints,
+                              mean.observed = mean.observed)
+  beta0 <- listBeta0$numeric
+  labelBeta0 <- listBeta0$label
+
   # quadratic terms 
   listOmegaEtaXi <- omegaAndSortedXis$omegaEtaXi
   omegaEtaXi <- listOmegaEtaXi$numeric
@@ -132,12 +146,26 @@ specifyModelDA <- function(syntax = NULL,
   selectScalingY <- selectScalingY(lambdaY, method = method)
   selectBetaRows <- selectBetaRows(lambdaY, method = method)
   emptyR <- constructR(etas, indsEtas, lambdaY, method = method)
-  scalingInds <- getScalingInds(allIndsEtas, R = emptyR, method = method)
+  fullR <- constructFullR(etas, indsEtas, lambdaY, method = method)
+
+  latentEtas <- getLatentEtasQml(indsEtas, method = method)
+  colsU <- getColsU(etas, indsEtas, lambdaY, method = method)
+
+  fullL2 <- constructFullL2(colsU, etas = etas, method = method)
+  selectSubL2 <- getSelectSubL2(fullL2, colsU = colsU, latentEtas = latentEtas, 
+                                method = method)
+  fullSigma2ThetaEpsilon <- constructFullSigma2ThetaEpsilon(psi, method = method)
+  selectSubSigma2ThetaEpsilon <- 
+    getSelectSubSigma2ThetaEpsilon(fullSigma2ThetaEpsilon, latentEtas = latentEtas, 
+                                   method = method)
+  fullU <- constructFullU(fullL2 = fullL2, N = NROW(data), etas = etas, method = method)
+
+  scalingInds <- getScalingInds(indsEtas, R = emptyR, latentEtas = latentEtas, method = method)
   selectThetaEpsilon <- selectThetaEpsilon(lambdaY, thetaEpsilon, 
                                            scalingInds, method = method)
   subThetaEpsilon <- constructSubThetaEpsilon(indsEtas, thetaEpsilon, 
                                               scalingInds, method = method)
-  
+
   covModel <- covModel(cov.syntax, method = method, parTable = parTableCovModel)
 
   # list of matrices
@@ -155,12 +183,22 @@ specifyModelDA <- function(syntax = NULL,
     tauX = tauX,
     tauY = tauY,
     alpha = alpha,
+    beta0 = beta0,
     omegaEtaXi = omegaEtaXi,
     omegaXiXi = omegaXiXi,
     selectScalingY = selectScalingY,
     selectThetaEpsilon = selectThetaEpsilon,
     selectBetaRows = selectBetaRows,
     emptyR = emptyR,
+    fullR = fullR,
+    fullSigma2ThetaEpsilon = fullSigma2ThetaEpsilon, 
+    selectSubSigma2ThetaEpsilon = selectSubSigma2ThetaEpsilon,
+    fullL2 = fullL2,
+    selectSubL2 = selectSubL2,
+    fullU = fullU,
+    colsU = colsU,
+    colsR = colnames(emptyR),
+    rowsR = rownames(emptyR),
     subThetaEpsilon = subThetaEpsilon)
 
   labelMatrices <- list(
@@ -176,6 +214,7 @@ specifyModelDA <- function(syntax = NULL,
     tauX = labelTauX,
     tauY = labelTauY,
     alpha = labelAlpha,
+    beta0 = labelBeta0,
     omegaEtaXi = labelOmegaEtaXi,
     omegaXiXi = labelOmegaXiXi)
 
@@ -184,6 +223,7 @@ specifyModelDA <- function(syntax = NULL,
 
   model <- list(info =
                 list(etas = etas,
+                     latentEtas = latentEtas,
                      numEtas = numEtas,
                      indsEtas = indsEtas,
                      allIndsEtas = allIndsEtas,
@@ -193,7 +233,8 @@ specifyModelDA <- function(syntax = NULL,
                      indsXis = indsXis,
                      allIndsXis = allIndsXis,
                      scalingInds = scalingInds,
-                     kOmegaEta = getK_NA(omegaEtaXi)),
+                     kOmegaEta = getK_NA(omegaEtaXi),
+                     lavOptimizerSyntaxAdditions = lavOptimizerSyntaxAdditions),
                 quad = quad,
                 matrices = matrices,
                 labelMatrices = labelMatrices,
@@ -244,28 +285,30 @@ create.theta <- function(model, start = NULL) {
   tauX <- as.vector(matrices$tauX)
   tauY <- as.vector(matrices$tauY)
   alpha <- as.vector(matrices$alpha)
+  beta0 <- as.vector(matrices$beta0)
   gammaXi <- as.vector(matrices$gammaXi)
   gammaEta <- as.vector(matrices$gammaEta)
   omegaXiXi <- as.vector(matrices$omegaXiXi)
   omegaEtaXi <- as.vector(matrices$omegaEtaXi)
   thetaMain <- c("lambdaX" = lambdaX,
-                      "lambdaY" = lambdaY,
-                      "tauX" = tauX,
-                      "tauY" = tauY,
-                      "thetaDelta" = thetaDelta,
-                      "thetaEpsilon" = thetaEpsilon,
-                      "phi" = phi,
-                      "A" = A,
-                      "psi" = psi,
-                      "alpha" = alpha,
-                      "gammaXi" = gammaXi,
-                      "gammaEta" = gammaEta,
-                      "omegaXiXi" = omegaXiXi,
-                      "omegaEtaXi" = omegaEtaXi)
+                 "lambdaY" = lambdaY,
+                 "tauX" = tauX,
+                 "tauY" = tauY,
+                 "thetaDelta" = thetaDelta,
+                 "thetaEpsilon" = thetaEpsilon,
+                 "phi" = phi,
+                 "A" = A,
+                 "psi" = psi,
+                 "alpha" = alpha,
+                 "beta0" = beta0,
+                 "gammaXi" = gammaXi,
+                 "gammaEta" = gammaEta,
+                 "omegaXiXi" = omegaXiXi,
+                 "omegaEtaXi" = omegaEtaXi)
   thetaMain <- thetaMain[is.na(thetaMain)]
   if (is.null(start)) {
    thetaMain <- vapply(thetaMain, FUN.VALUE = vector("numeric", 1L),
-                            FUN = function(x) stats::runif(1))
+                       FUN = function(x) stats::runif(1))
   }
 
   theta <- c(thetaLabel, thetaCov, thetaMain)
@@ -298,8 +341,10 @@ fillModel <- function(model, theta, fillPhi = FALSE, method = "lms") {
     thetaMain <- theta[-seq_len(model$lenThetaCov)]
   }
 
+
   model$covModel <- fillCovModel(model$covModel, thetaCov, thetaLabel,
-                                 fillPhi = fillPhi, method = method)
+                                  fillPhi = fillPhi, method = method)
+  
   model$matrices <- fillMainModel(model, thetaMain, thetaLabel,
                                   fillPhi = fillPhi, method = method)
   model
@@ -329,40 +374,26 @@ fillMainModel <- function(model, theta, thetaLabel, fillPhi = FALSE,
     fillSymmetric(matrices$thetaEpsilon, 
                   fetch(theta, "thetaEpsilon[0-9]*$"))
 
-  if (method == "lms") {
-    if (!is.null(model$covModel$matrices)) {
-      matrices$A <- expectedCovModel(model$covModel, method = "lms", 
-                                     sortedXis = xis)
-    } else {
+  if (!is.null(model$covModel$matrices)) {
+      matrices$phi <- matrices$A <- 
+        expectedCovModel(model$covModel, method = method, sortedXis = xis)
+
+  } else if (method == "lms") {
       matrices$A[is.na(matrices$A)] <- fetch(theta, "^A[0-9]*$")
-    }
-  } else if (method == "qml"){
-    if (!is.null(model$covModel$matrices)) {
-      matrices$phi <- expectedCovModel(model$covModel, method = "qml",
-                                       sortedXis = xis)
-    } else {
-      matrices$phi <- fillSymmetric(matrices$phi, 
-                                    fetch(theta, "^phi[0-9]*$"))
-    }
+
+  } else if (method == "qml") {
+      matrices$phi <- fillSymmetric(matrices$phi, fetch(theta, "^phi[0-9]*$"))
   }
 
-  matrices$psi <- fillSymmetric(matrices$psi, 
-                                fetch(theta, "^psi[0-9]*$"))
-
-  matrices$tauX[is.na(matrices$tauX)] <-
-    fetch(theta, "tauX[0-9]*$")
-  matrices$tauY[is.na(matrices$tauY)] <-
-    fetch(theta, "tauY[0-9]*$")
-  matrices$alpha[is.na(matrices$alpha)] <-
-    fetch(theta, "alpha[0-9]*$")
-  matrices$gammaEta[is.na(matrices$gammaEta)] <-
-    fetch(theta, "gammaEta[0-9]*$")
-  matrices$gammaXi[is.na(matrices$gammaXi)] <-
-    fetch(theta, "gammaXi[0-9]*$")
-  matrices$omegaXiXi[is.na(matrices$omegaXiXi)] <-
-    fetch(theta, "omegaXiXi[0-9]*$")
-  matrices$omegaEtaXi[is.na(matrices$omegaEtaXi)] <-
-    fetch(theta, "omegaEtaXi[0-9]*$")
+  matrices$psi <- fillSymmetric(matrices$psi, fetch(theta, "^psi[0-9]*$"))
+  matrices$tauX[is.na(matrices$tauX)] <- fetch(theta, "tauX[0-9]*$")
+  matrices$tauY[is.na(matrices$tauY)] <- fetch(theta, "tauY[0-9]*$")
+  matrices$alpha[is.na(matrices$alpha)] <- fetch(theta, "alpha[0-9]*$")
+  matrices$beta0[is.na(matrices$beta0)] <- fetch(theta, "beta0[0-9]*$")
+  matrices$gammaEta[is.na(matrices$gammaEta)] <- fetch(theta, "gammaEta[0-9]*$")
+  matrices$gammaXi[is.na(matrices$gammaXi)] <- fetch(theta, "gammaXi[0-9]*$")
+  matrices$omegaXiXi[is.na(matrices$omegaXiXi)] <- fetch(theta, "omegaXiXi[0-9]*$")
+  matrices$omegaEtaXi[is.na(matrices$omegaEtaXi)] <- fetch(theta, "omegaEtaXi[0-9]*$")
   if (fillPhi) matrices$phi <- matrices$A %*% t(matrices$A)
   matrices
 }
@@ -541,6 +572,14 @@ mainModelToParTable <- function(finalModel, method = "lms") {
                               op = "~",
                               rowsLhs = TRUE)
   parTable <- rbind(parTable, newRows)
+  
+  newRows <- matrixToParTable(matricesNA$beta0,
+                              matricesEst$beta0,
+                              matricesSE$beta0,
+                              matricesLabel$beta0,
+                              op = "~",
+                              rowsLhs = TRUE)
+  parTable <- rbind(parTable, newRows)
 
   # Residual (co) variances Measurement Model 
   newRows <- matrixToParTable(matricesNA$thetaDelta,
